export type LogLevel = 'verbose' | 'info' | 'warn' | 'error';

export interface LoggerOptions {
  level?: LogLevel;
  enabled?: boolean;
}

const levels: Record<LogLevel, number> = {
  verbose: 0,
  info: 1,
  warn: 2,
  error: 3,
};

export class Logger {
  private namespace: string;
  private level: LogLevel;
  private enabled: boolean;

  constructor(namespace: string, options: LoggerOptions = {}) {
    this.namespace = namespace;
    this.level = options.level || 'info';
    this.enabled = options.enabled ?? true;
  }

  private shouldLog(msgLevel: LogLevel): boolean {
    return this.enabled && levels[msgLevel] >= levels[this.level];
  }

  verbose(...args: any[]): void {
    if (this.shouldLog('verbose')) {
      console.log(`[${this.namespace}]`, ...args);
    }
  }

  info(...args: any[]): void {
    if (this.shouldLog('info')) {
      console.info(`[${this.namespace}]`, ...args);
    }
  }

  warn(...args: any[]): void {
    if (this.shouldLog('warn')) {
      console.warn(`[${this.namespace}]`, ...args);
    }
  }

  error(...args: any[]): void {
    if (this.shouldLog('error')) {
      console.error(`[${this.namespace}]`, ...args);
    }
  }
}

export function createLogger(namespace: string, options?: LoggerOptions): Logger {
  return new Logger(namespace, options);
}
