import {isMatch} from 'micromatch';

/**
 * Creates a file pattern matcher function
 * @param patterns - Glob patterns to match files
 * @returns A function that returns true if the file matches the patterns
 */
export function createPatternMatcher(patterns?: string | string[]) {
  if (!patterns) return () => true;

  const patternArray = Array.isArray(patterns) ? patterns : [patterns];
  const includePatterns = patternArray.filter(p => !p.startsWith('!'));
  const excludePatterns = patternArray.filter(p => p.startsWith('!')).map(p => p.slice(1));

  return (fileName: string): boolean => {
    return isMatch(fileName, includePatterns, {
      dot: true,
      ignore: excludePatterns,
    });
  };
}
